@@ -64,7 +64,7 @@ func (c *UnpinCommand) Run(ctx context.Context, originalArgs []string) error {
 
 	fsys := os.DirFS(".")
 
-	files, err := loadYAMLFiles(fsys, args)
+	files, err := loadYAMLFiles(fsys, args, true)
 	if err != nil {
 		return err
 	}
